@@ -213,6 +213,13 @@ class FKeyManager:
                     self.monitor.ui.show_status(),
                 ),
             ),
+            FKey(
+                cmd="TOGGLE-GRID-LAYOUT",
+                game_key="F9",
+                curses_key=curses.KEY_F9,
+                status=lambda: self.monitor.ui.grid_layout.value.name,
+                handler=lambda m: self.monitor.ui.cycle_grid_layout(),
+            ),
             FKey(
                 cmd="SINGLE-STEP",
                 game_key="KP_DEL",
